
export function isSupported() {

    let result = true;

    if (!("Notification" in window)) {
        result = false;
    }

    return result;
}

export async function getServiceWorkerRegistration() {

    let registration = null;

    if (navigator && navigator.serviceWorker) {
        registration = await navigator.serviceWorker.getRegistration();
    }

    return registration;
}

export async function getNotifications() {

    let notifications = [];

    if (isSupported()) {
        let registration = await getServiceWorkerRegistration();
        if (registration) {
            notifications = await registration.getNotifications();
        }
    }

    return notifications;
}

export function getPermission() { // default, granted, denied, unsupported

    let result = 'unsupported';

    if (isSupported()) {
        result = Notification.permission;
    }

    return result;
}

export async function askNotificationPermission() {

    let result = getPermission();

    if (result == 'default') {
        try {
            result = await Notification.requestPermission();
        }
        catch (ex) {

            let waitUser = true;

            Notification.requestPermission((permission) => {
                result = permission;
                waitUser = false;
            });

            while (waitUser) {
                await new Promise(resolve => {
                    return setTimeout(resolve, 1000)
                });
            }
        }
    }

    return result;
}

export async function showNotification(title, body, badge, icon, image, tag) {

    let options = {
        body: body,
        silent: false,
        vibrate: [ 300, 300 ],
    }

    if (badge)
        options.badge = badge;

    if (icon)
        options.icon = icon;

    if (image)
        options.image = image;

    if (tag)
    {
        options.tag = tag;
        options.renotify = true;
    }

    let registration = await getServiceWorkerRegistration();
    if (registration) {
        registration.showNotification(title, options)
    }
}

export async function closeNotification(tag) {
    if (isSupported()) {

        let notifications = await getNotifications();
        notifications.forEach(function (notification) {

            if (tag == null || tag == notification.tag) {
                notification.close();
            }
        });
    }
}